# build options
%global _pkgname %(rpm -q --quiet dnf && echo dnf || echo yum)

# systemd options
%global _has_systemd %(rpm -q --quiet systemd && systemctl --version | head -n 1 | cut -d " " -f 2 || echo 0)
%if %{_has_systemd}
  # this is usually either `common.service' or `%{_has_systemd}.service'
  %global _servicefile_postfix common.service
  %global _pidbasedir /run
%else
  %global _servicefile_postfix init
  %global _pidbasedir %{_var}/run
%endif

Summary: Pkgmonitor manages system packages
Name: pkgmonitor
Version: 2.2.37
Release: 1%{?dist}
Group: System Environment/Daemons
License: GPL-2.0-or-later
Packager: Simon Matter <simon.matter@invoca.ch>
Vendor: Invoca Systems
Distribution: Invoca Linux Server
Source0: %{name}.%{_servicefile_postfix}
Source1: %{name}.sysconfig
Source2: %{name}.sh.in
Source3: pkgchangelog.sh
%if %{_has_systemd}
Source4: %{name}-tmpfiles.conf
%endif
Source5: README.%{name}
Source6: CREDITS.%{name}
Source7: http://www.gnu.org/licenses/gpl.txt
Requires: sendemail >= 1.50, %{_pkgname}, sed, zabbix, invocautils, yum-utils
%if "%{_pkgname}" == "yum"
Requires: rsync
%endif
%if %{_has_systemd}
BuildRequires: systemd
%systemd_requires
%else
Requires(post): /sbin/chkconfig
Requires(preun): /sbin/chkconfig, /sbin/service
Requires(postun): /sbin/service
%endif
BuildRequires: sed
BuildArch: noarch
BuildRoot: %{_tmppath}/%{name}-%{version}-root

%description
Pkgmonitor periodically checks for updatable packages and lists
them. It can also install, up- or downgrade packages on request.
Additionally it can show if your running kernel is the default
kernel configured for your system. It is meant to be called from
system monitoring tools like Zabbix https://www.zabbix.com but
can also be used standalone.

%prep
%{__install} -d %{_builddir}/%{name}-%{version}
%{__install} -m 0644 -p %{SOURCE5} %{_builddir}/%{name}-%{version}/README
%{__install} -m 0644 -p %{SOURCE6} %{_builddir}/%{name}-%{version}/CREDITS
%{__install} -m 0644 -p %{SOURCE7} %{_builddir}/%{name}-%{version}/LICENSE

%install
[ "%{buildroot}" != "/" ] && %{__rm} -rf %{buildroot}

%{__install} -d %{buildroot}%{_sysconfdir}/sysconfig
%{__install} -d %{buildroot}%{_bindir}
%{__install} -d %{buildroot}%{_pidbasedir}/%{name}
%{__install} -d %{buildroot}%{_var}/cache/%{name}

%if %{_has_systemd}
%{__install} -d %{buildroot}%{_prefix}/lib/tmpfiles.d
%{__install} -d %{buildroot}%{_unitdir}
%{__install} -m 0644 -p %{SOURCE4} %{buildroot}%{_prefix}/lib/tmpfiles.d/%{name}.conf
%{__install} -m 0644 -p %{SOURCE0} %{buildroot}%{_unitdir}/%{name}.service
%else
%{__install} -d %{buildroot}%{_initrddir}
%{__install} -m 0755 -p %{SOURCE0} %{buildroot}%{_initrddir}/%{name}
%endif

%{__install} -m 0644 -p %{SOURCE1} %{buildroot}%{_sysconfdir}/sysconfig/%{name}
%{__sed} -e "s@\/var\/run\/@%{_pidbasedir}/@g" %{SOURCE2} > %{buildroot}%{_bindir}/%{name}
%{__chmod} 0755 %{buildroot}%{_bindir}/%{name}
%{__install} -m 0755 -p %{SOURCE3} %{buildroot}%{_bindir}/pkgchangelog

%clean
[ "%{buildroot}" != "/" ] && %{__rm} -rf %{buildroot}

%post
%if %{_has_systemd}
%systemd_post %{name}.service
%else
/sbin/chkconfig --add %{name}
%endif

%preun
%if %{_has_systemd}
%systemd_preun %{name}.service
%else
if [ $1 -eq 0 ]; then
  /sbin/service %{name} stop > /dev/null 2>&1 || :
  /sbin/chkconfig --del %{name}
fi
%endif

%postun
%if %{_has_systemd}
%{_bindir}/systemctl daemon-reload > /dev/null 2>&1 || :
if [ $1 -ge 1 ]; then
  %{_bindir}/%{name} try-restart > /dev/null 2>&1 || :
fi
%else
if [ $1 -ge 1 ]; then
  /sbin/service %{name} condrestart > /dev/null 2>&1 || :
fi
%endif

%files
%defattr(-,root,root,-)
%doc %{name}-%{version}/README %{name}-%{version}/CREDITS %{name}-%{version}/LICENSE
%{_bindir}/%{name}
%{_bindir}/pkgchangelog
%dir %{_var}/cache/%{name}
%config(noreplace) %{_sysconfdir}/sysconfig/%{name}
%if %{_has_systemd}
%{_prefix}/lib/tmpfiles.d/%{name}.conf
%{_unitdir}/%{name}.service
%else
%config %{_initrddir}/%{name}
%endif
%dir %{_pidbasedir}/%{name}

%changelog
* Sat Jun 21 2025 Simon Matter <simon.matter@invoca.ch> 2.2.37-1
- improve output of listall function

* Thu Jan 23 2025 Simon Matter <simon.matter@invoca.ch> 2.2.36-1
- improve subject in emails sent

* Thu Jan 16 2025 Simon Matter <simon.matter@invoca.ch> 2.2.35-1
- remove Security: rentries from package list

* Fri May 31 2024 Simon Matter <simon.matter@invoca.ch> 2.2.34-1
- change efisync description

* Tue May 28 2024 Simon Matter <simon.matter@invoca.ch> 2.2.33-1
- add randomness to check interval

* Thu May 23 2024 Simon Matter <simon.matter@invoca.ch> 2.2.32-1
- set default of $PKG_INSTALLONLY_LIMIT to 3

* Fri Apr 26 2024 Simon Matter <simon.matter@invoca.ch> 2.2.31-1
- improve status mail sent with cron function

* Thu Apr 25 2024 Simon Matter <simon.matter@invoca.ch> 2.2.30-1
- fix and enhance status mail sent with cron function
- require sendemail instead of sendEmail

* Wed Mar 06 2024 Simon Matter <simon.matter@invoca.ch> 2.2.29-1
- show (none) as changelog if there were no changes

* Wed Mar 06 2024 Simon Matter <simon.matter@invoca.ch> 2.2.28-1
- fix generation of packages list for changelogs

* Mon Feb 12 2024 Simon Matter <simon.matter@invoca.ch> 2.2.27-1
- adjust $RBT_PKG_LIST to new distributions

* Thu Feb 01 2024 Simon Matter <simon.matter@invoca.ch> 2.2.26-1
- fix version information in changelog of EL9 kernel packages
- change to SPDX license tag

* Wed Jun 14 2023 Simon Matter <simon.matter@invoca.ch> 2.2.25-4
- cosmetic spec file changes

* Mon Mar 06 2023 Simon Matter <simon.matter@invoca.ch> 2.2.25-3
- add also Wants=network-online.target to systemd unit files

* Fri Mar 03 2023 Simon Matter <simon.matter@invoca.ch> 2.2.25-2
- add network-online requirement to systemd unit files

* Thu Jan 26 2023 Simon Matter <simon.matter@invoca.ch> 2.2.25-1
- cosmetic changes

* Wed Jan 25 2023 Simon Matter <simon.matter@invoca.ch> 2.2.24-1
- add package summaries to changelog output

* Mon Jan 23 2023 Simon Matter <simon.matter@invoca.ch> 2.2.23-1
- cosmetic changes

* Mon Jan 23 2023 Simon Matter <simon.matter@invoca.ch> 2.2.22-1
- improve mechanism for reexec

* Fri Jan 20 2023 Simon Matter <simon.matter@invoca.ch> 2.2.21-1
- refactoring for new bash style

* Fri Nov 18 2022 Simon Matter <simon.matter@invoca.ch> 2.2.20-1
- remove some unneeded \ from grep
- optimize the order of how lists are activated

* Sat Nov 12 2022 Simon Matter <simon.matter@invoca.ch> 2.2.19-1
- cleanup cache files if DNF/YUM check-upgrade failed
- correctly state if number of upgradable packages is unknown

* Sat Nov 12 2022 Simon Matter <simon.matter@invoca.ch> 2.2.16-1
- fix unbound variable errors when certain read() fails

* Sat Sep 03 2022 Simon Matter <simon.matter@invoca.ch> 2.2.15-1
- add `(kernel excluded)' to `suggesting a reboot' message

* Wed Aug 03 2022 Simon Matter <simon.matter@invoca.ch> 2.2.14-1
- simplify string checks
- cosmetic changes

* Tue Jan 18 2022 Simon Matter <simon.matter@invoca.ch> 2.2.13-1
- improve check_interval loop

* Mon Jan 17 2022 Simon Matter <simon.matter@invoca.ch> 2.2.12-1
- improve `try-restart' handling

* Mon Jan 17 2022 Simon Matter <simon.matter@invoca.ch> 2.2.11-1
- fix parsing of DNF/YUM log files

* Thu Jan 13 2022 Simon Matter <simon.matter@invoca.ch> 2.2.10-2
- cosmetic fixes

* Wed Jan 12 2022 Simon Matter <simon.matter@invoca.ch> 2.2.10-1
- cosmetic fixes

* Thu Sep 02 2021 Simon Matter <simon.matter@invoca.ch> 2.2.9-1
- fix cleaning up of temporary files

* Sat Aug 28 2021 Simon Matter <simon.matter@invoca.ch> 2.2.8-1
- add some small optimizations

* Thu Aug 26 2021 Simon Matter <simon.matter@invoca.ch> 2.2.7-1
- set $MAIN_PID in control instance
- add type `rbtlist' to wait_list()

* Wed Aug 25 2021 Simon Matter <simon.matter@invoca.ch> 2.2.6-1
- fix new logic for reboot list

* Tue Aug 24 2021 Simon Matter <simon.matter@invoca.ch> 2.2.5-1
- add some small fixes

* Tue Aug 24 2021 Simon Matter <simon.matter@invoca.ch> 2.2.4-1
- improve output format of list/listall

* Tue Aug 24 2021 Simon Matter <simon.matter@invoca.ch> 2.2.3-1
- improve output format of list/listall

* Tue Aug 24 2021 Simon Matter <simon.matter@invoca.ch> 2.2.2-1
- improve output of running upgraded packages

* Tue Aug 24 2021 Simon Matter <simon.matter@invoca.ch> 2.2.1-1
- improve output of running upgraded packages

* Tue Aug 24 2021 Simon Matter <simon.matter@invoca.ch> 2.2.0-1
- check for upgraded packages which suggest a reboot to fully apply

* Thu Aug 19 2021 Simon Matter <simon.matter@invoca.ch> 2.1.6-3
- improve init script

* Wed Aug 18 2021 Simon Matter <simon.matter@invoca.ch> 2.1.6-2
- fix inconsistency between init scripts and systemd

* Tue Aug 17 2021 Simon Matter <simon.matter@invoca.ch> 2.1.6-1
- revert some init changes and fix them

* Tue Aug 17 2021 Simon Matter <simon.matter@invoca.ch> 2.1.5-2
- adopt pre/post scripts to changed init system

* Tue Aug 17 2021 Simon Matter <simon.matter@invoca.ch> 2.1.5-1
- fixes in the init system

* Tue Aug 17 2021 Simon Matter <simon.matter@invoca.ch> 2.1.4-1
- more fixes for daemon mode

* Tue Aug 17 2021 Simon Matter <simon.matter@invoca.ch> 2.1.3-1
- more fixes for daemon mode

* Sat Aug 14 2021 Simon Matter <simon.matter@invoca.ch> 2.1.2-1
- more fixes for daemon mode

* Fri Aug 13 2021 Simon Matter <simon.matter@invoca.ch> 2.1.1-1
- reset bash variables in daemon mode

* Fri Aug 13 2021 Simon Matter <simon.matter@invoca.ch> 2.1.0-1
- set proctitle in daemon mode

* Tue Aug 10 2021 Simon Matter <simon.matter@invoca.ch> 2.0.22-1
- add proxy host to $NO_PROXY list

* Tue Jun 08 2021 Simon Matter <simon.matter@invoca.ch> 2.0.21-1
- use "command -v" instead of "hash"

* Mon Apr 12 2021 Simon Matter <simon.matter@invoca.ch> 2.0.20-1
- fix wildcards in package list to really work

* Fri Mar 19 2021 Simon Matter <simon.matter@invoca.ch> 2.0.19-1
- allow wildcards in list of packages

* Mon Mar 01 2021 Simon Matter <simon.matter@invoca.ch> 2.0.18-1
- improve ordering of tasks after upgrades

* Wed Jan 20 2021 Simon Matter <simon.matter@invoca.ch> 2.0.17-1
- improve wording about merging

* Wed Jan 20 2021 Simon Matter <simon.matter@invoca.ch> 2.0.15-1
- improve exit handling of 'rpmconfigmerge'

* Tue Jan 05 2021 Simon Matter <simon.matter@invoca.ch> 2.0.14-2
- upgrade bundled pkgchangelog to version 0.9.7

* Thu Dec 31 2020 Simon Matter <simon.matter@invoca.ch> 2.0.14-1
- upgrade to 2.0.14

* Thu Dec 31 2020 Simon Matter <simon.matter@invoca.ch> 2.0.13-1
- upgrade to 2.0.13

* Fri Dec 11 2020 Simon Matter <simon.matter@invoca.ch> 2.0.12-1
- upgrade to 2.0.12
- upgrade bundled pkgchangelog to version 0.9.4
- add support for EL8

* Wed Dec 02 2020 Simon Matter <simon.matter@invoca.ch> 2.0.11-1
- upgrade to 2.0.11

* Mon Nov 23 2020 Simon Matter <simon.matter@invoca.ch> 2.0.10-1
- upgrade to 2.0.10

* Thu Nov 19 2020 Simon Matter <simon.matter@invoca.ch> 2.0.9-1
- upgrade to 2.0.9

* Tue Oct 27 2020 Simon Matter <simon.matter@invoca.ch> 2.0.8-1
- upgrade to 2.0.8

* Mon Oct 26 2020 Simon Matter <simon.matter@invoca.ch> 2.0.7-1
- upgrade to 2.0.7

* Fri Oct 23 2020 Simon Matter <simon.matter@invoca.ch> 2.0.6-3
- upgrade bundled pkgchangelog to version 0.9.3

* Fri Oct 02 2020 Simon Matter <simon.matter@invoca.ch> 2.0.6-2
- upgrade bundled pkgchangelog to version 0.9.2

* Fri Oct 02 2020 Simon Matter <simon.matter@invoca.ch> 2.0.6-1
- upgrade to 2.0.6

* Fri Oct 02 2020 Simon Matter <simon.matter@invoca.ch> 2.0.5-1
- upgrade to 2.0.5

* Thu Oct 01 2020 Simon Matter <simon.matter@invoca.ch> 2.0.4-1
- upgrade to 2.0.4

* Fri Sep 25 2020 Simon Matter <simon.matter@invoca.ch> 2.0.3-1
- upgrade to 2.0.3

* Fri Sep 25 2020 Simon Matter <simon.matter@invoca.ch> 2.0.2-1
- upgrade to 2.0.2

* Fri Sep 25 2020 Simon Matter <simon.matter@invoca.ch> 2.0.1-1
- upgrade to 2.0.1

* Fri Sep 25 2020 Simon Matter <simon.matter@invoca.ch> 2.0.0-1
- upgrade to 2.0.0

* Fri Aug 14 2020 Simon Matter <simon.matter@invoca.ch> 1.6.9-1
- upgrade to 1.6.9

* Fri Aug 14 2020 Simon Matter <simon.matter@invoca.ch> 1.6.8-1
- upgrade to 1.6.8

* Thu Aug 13 2020 Simon Matter <simon.matter@invoca.ch> 1.6.7-1
- upgrade to 1.6.7

* Wed Aug 12 2020 Simon Matter <simon.matter@invoca.ch> 1.6.6-1
- upgrade to 1.6.6

* Fri Aug 07 2020 Simon Matter <simon.matter@invoca.ch> 1.6.5-1
- upgrade to 1.6.5

* Thu Aug 06 2020 Simon Matter <simon.matter@invoca.ch> 1.6.4-1
- upgrade to 1.6.4

* Wed Aug 05 2020 Simon Matter <simon.matter@invoca.ch> 1.6.3-1
- upgrade to 1.6.3

* Wed Apr 22 2020 Simon Matter <simon.matter@invoca.ch> 1.6.2-1
- upgrade to 1.6.2

* Mon Apr 20 2020 Simon Matter <simon.matter@invoca.ch> 1.6.1-1
- upgrade to 1.6.1

* Fri Apr 17 2020 Simon Matter <simon.matter@invoca.ch> 1.6.0-1
- upgrade to 1.6.0
- add support for EL8

* Thu Apr 25 2019 Simon Matter <simon.matter@invoca.ch> 1.5.0-1
- upgrade to 1.5.0

* Fri Mar 01 2019 Simon Matter <simon.matter@invoca.ch> 1.4.24-1
- upgrade to 1.4.24

* Mon Jan 28 2019 Simon Matter <simon.matter@invoca.ch> 1.4.23-2
- add dependencies for rpmconfigmerge

* Thu Sep 20 2018 Simon Matter <simon.matter@invoca.ch> 1.4.23-1
- upgrade to 1.4.23

* Fri Aug 31 2018 Simon Matter <simon.matter@invoca.ch> 1.4.22-1
- upgrade to 1.4.22

* Fri Aug 31 2018 Simon Matter <simon.matter@invoca.ch> 1.4.21-1
- upgrade to 1.4.21

* Fri Aug 31 2018 Simon Matter <simon.matter@invoca.ch> 1.4.20-1
- upgrade to 1.4.20

* Wed Jul 18 2018 Simon Matter <simon.matter@invoca.ch> 1.4.19-1
- upgrade to 1.4.19

* Wed Jun 27 2018 Simon Matter <simon.matter@invoca.ch> 1.4.18-1
- upgrade to 1.4.18

* Mon Jun 25 2018 Simon Matter <simon.matter@invoca.ch> 1.4.17-1
- upgrade to 1.4.17

* Sat Jun 23 2018 Simon Matter <simon.matter@invoca.ch> 1.4.16-1
- upgrade to 1.4.16

* Wed May 16 2018 Simon Matter <simon.matter@invoca.ch> 1.4.15-1
- upgrade to 1.4.15

* Fri Apr 27 2018 Simon Matter <simon.matter@invoca.ch> 1.4.14-1
- upgrade to 1.4.14

* Fri Apr 27 2018 Simon Matter <simon.matter@invoca.ch> 1.4.13-1
- upgrade to 1.4.13

* Fri Apr 27 2018 Simon Matter <simon.matter@invoca.ch> 1.4.12-1
- upgrade to 1.4.12

* Fri Apr 27 2018 Simon Matter <simon.matter@invoca.ch> 1.4.11-1
- upgrade to 1.4.11

* Thu Mar 29 2018 Simon Matter <simon.matter@invoca.ch> 1.4.10-1
- upgrade to 1.4.10

* Tue Mar 20 2018 Simon Matter <simon.matter@invoca.ch> 1.4.9-1
- upgrade to 1.4.9

* Tue Mar 20 2018 Simon Matter <simon.matter@invoca.ch> 1.4.8-1
- upgrade to 1.4.8

* Mon Mar 12 2018 Simon Matter <simon.matter@invoca.ch> 1.4.7-1
- upgrade to 1.4.7

* Thu Mar 08 2018 Simon Matter <simon.matter@invoca.ch> 1.4.6-1
- upgrade to 1.4.6

* Tue Mar 06 2018 Simon Matter <simon.matter@invoca.ch> 1.4.5-1
- upgrade to 1.4.5

* Fri Mar 02 2018 Simon Matter <simon.matter@invoca.ch> 1.4.4-1
- upgrade to 1.4.4

* Wed Jan 31 2018 Simon Matter <simon.matter@invoca.ch> 1.4.3-1
- upgrade to 1.4.3

* Wed Jan 31 2018 Simon Matter <simon.matter@invoca.ch> 1.4.2-1
- upgrade to 1.4.2

* Fri Jan 19 2018 Simon Matter <simon.matter@invoca.ch> 1.4.1-1
- upgrade to 1.4.1

* Thu Jan 18 2018 Simon Matter <simon.matter@invoca.ch> 1.4.0-1
- upgrade to 1.4.0

* Fri Oct 06 2017 Simon Matter <simon.matter@invoca.ch> 1.3.7-1
- upgrade to 1.3.7

* Wed Sep 20 2017 Simon Matter <simon.matter@invoca.ch> 1.3.6-1
- upgrade to 1.3.6

* Wed Sep 20 2017 Simon Matter <simon.matter@invoca.ch> 1.3.5-1
- upgrade to 1.3.5

* Wed Sep 20 2017 Simon Matter <simon.matter@invoca.ch> 1.3.4-1
- upgrade to 1.3.4

* Sat Sep 16 2017 Simon Matter <simon.matter@invoca.ch> 1.3.3-1
- upgrade to 1.3.3

* Fri Sep 15 2017 Simon Matter <simon.matter@invoca.ch> 1.3.2-1
- upgrade to 1.3.2

* Fri Sep 15 2017 Simon Matter <simon.matter@invoca.ch> 1.3.1-1
- upgrade to 1.3.1

* Thu Sep 14 2017 Simon Matter <simon.matter@invoca.ch> 1.3.0-1
- upgrade to 1.3.0

* Tue Aug 22 2017 Simon Matter <simon.matter@invoca.ch> 1.2.5-1
- upgrade to 1.2.5

* Tue Jun 06 2017 Simon Matter <simon.matter@invoca.ch> 1.2.4-1
- upgrade to 1.2.4

* Tue Jun 06 2017 Simon Matter <simon.matter@invoca.ch> 1.2.3-1
- upgrade to 1.2.3

* Thu Apr 20 2017 Simon Matter <simon.matter@invoca.ch> 1.2.2-1
- upgrade to 1.2.2

* Wed May 25 2016 Simon Matter <simon.matter@invoca.ch> 1.2.1-1
- upgrade to 1.2.1

* Tue Nov 24 2015 Simon Matter <simon.matter@invoca.ch> 1.2.0-1
- upgrade to 1.2.0

* Wed Aug 26 2015 Simon Matter <simon.matter@invoca.ch> 1.1.7-1
- upgrade to 1.1.7

* Fri May 29 2015 Simon Matter <simon.matter@invoca.ch> 1.1.6-1
- upgrade to 1.1.6

* Thu May 28 2015 Simon Matter <simon.matter@invoca.ch> 1.1.5-1
- upgrade to 1.1.5

* Mon May 18 2015 Simon Matter <simon.matter@invoca.ch> 1.1.4-1
- upgrade to 1.1.4

* Wed May 13 2015 Simon Matter <simon.matter@invoca.ch> 1.1.3-1
- upgrade to 1.1.3

* Wed May 13 2015 Simon Matter <simon.matter@invoca.ch> 1.1.2-1
- upgrade to 1.1.2

* Wed May 13 2015 Simon Matter <simon.matter@invoca.ch> 1.1.0-2
- small spec fixes for systemd

* Tue May 12 2015 Simon Matter <simon.matter@invoca.ch> 1.1.0-1
- upgrade to 1.1.0

* Tue May 12 2015 Simon Matter <simon.matter@invoca.ch> 1.0.1-2
- fix build for systemd

* Wed Apr 29 2015 Simon Matter <simon.matter@invoca.ch> 1.0.1-1
- upgrade to 1.0.1

* Tue Apr 28 2015 Simon Matter <simon.matter@invoca.ch> 1.0.0-1
- upgrade to 1.0.0
- add support for systemd

* Thu Mar 13 2014 Simon Matter <simon.matter@invoca.ch> 0.5.2-1
- update to 0.5.2

* Fri Aug 30 2013 Simon Matter <simon.matter@invoca.ch> 0.5.1-1
- update to 0.5.1

* Fri Aug 30 2013 Simon Matter <simon.matter@invoca.ch> 0.5.0-1
- update to 0.5.0

* Thu Mar 14 2013 Simon Matter <simon.matter@invoca.ch> 0.4.5-1
- update to 0.4.5

* Thu Mar 14 2013 Simon Matter <simon.matter@invoca.ch> 0.4.4-1
- update to 0.4.4

* Tue Jan 22 2013 Simon Matter <simon.matter@invoca.ch> 0.4.3-1
- update to 0.4.3

* Fri Nov 09 2012 Simon Matter <simon.matter@invoca.ch> 0.4.2-1
- update to 0.4.2

* Thu Nov 08 2012 Simon Matter <simon.matter@invoca.ch> 0.4.1-1
- update to 0.4.1

* Wed Nov 07 2012 Simon Matter <simon.matter@invoca.ch> 0.4.0-1
- update to 0.4.0

* Wed Jun 06 2012 Simon Matter <simon.matter@invoca.ch> 0.3.7-1
- update to 0.3.7

* Wed Aug 03 2011 Simon Matter <simon.matter@invoca.ch> 0.3.6-1
- update to 0.3.6

* Wed Aug 03 2011 Simon Matter <simon.matter@invoca.ch> 0.3.5-1
- update to 0.3.5

* Fri Apr 15 2011 Simon Matter <simon.matter@invoca.ch> 0.3.4-2
- mass rebuild

* Tue Feb 22 2011 Simon Matter <simon.matter@invoca.ch> 0.3.4-1
- update to 0.3.4

* Mon Feb 21 2011 Simon Matter <simon.matter@invoca.ch> 0.3.3-1
- update to 0.3.3

* Fri Feb 18 2011 Simon Matter <simon.matter@invoca.ch> 0.3.2-1
- update to 0.3.2

* Fri Feb 18 2011 Simon Matter <simon.matter@invoca.ch> 0.3.1-1
- update to 0.3.1

* Fri Jun 25 2010 Simon Matter <simon.matter@invoca.ch> 0.3.0-1
- update to 0.3.0

* Tue Sep 22 2009 Simon Matter <simon.matter@invoca.ch> 0.2.8-1
- update to 0.2.8
- clean metadata and packages after successful update

* Fri Jul 31 2009 Simon Matter <simon.matter@invoca.ch> 0.2.7-1
- update to 0.2.7
- clean metadata on startup and before update

* Fri May 01 2009 Simon Matter <simon.matter@invoca.ch> 0.2.6-1
- update to 0.2.6
- fix to work correctly with recent yum versions

* Thu Mar 19 2009 Simon Matter <simon.matter@invoca.ch> 0.2.5-1
- update to 0.2.5

* Thu Mar 19 2009 Simon Matter <simon.matter@invoca.ch> 0.2.4-1
- update to 0.2.4
- remove zabbix from requires

* Wed Mar 18 2009 Simon Matter <simon.matter@invoca.ch> 0.2.3-1
- update to 0.2.3

* Wed Mar 18 2009 Simon Matter <simon.matter@invoca.ch> 0.2.2-1
- update to 0.2.2

* Wed Mar 18 2009 Simon Matter <simon.matter@invoca.ch> 0.2.1-2
- fix pre/post scripts

* Wed Mar 18 2009 Simon Matter <simon.matter@invoca.ch> 0.2.1-1
- update to 0.2.1

* Mon Feb 09 2009 Simon Matter <simon.matter@invoca.ch> 0.2.0-1
- initial build
